require("kolter.set")
require("kolter.remap")

local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)

require("lazy").setup({
    { 'rose-pine/neovim' },
    { 'folke/tokyonight.nvim', lazy = false, priority = 1000 },
    { 'nvim-lua/plenary.nvim' },
    { 'mbbill/undotree' },
    { 'nvim-telescope/telescope.nvim', branch = '0.1.x' },
    { 'nvim-tree/nvim-tree.lua' },
    { 'nvim-tree/nvim-web-devicons' },
    { 'nvim-lualine/lualine.nvim' },
    { 'folke/trouble.nvim' },
    { 'folke/which-key.nvim', event = 'VeryLazy', init = function()
            vim.o.timeout = true
            vim.o.timeoutlen = 300
        end
    },
    { 'VonHeikemen/lsp-zero.nvim', branch = 'v3.x',
        dependencies = {
            -- LSP Support
            { 'neovim/nvim-lspconfig' },
            {
                'williamboman/mason.nvim',
                build = function()
                    pcall(vim.cmd, 'MasonUpdate')
                end,
            },
            { 'williamboman/mason-lspconfig.nvim' },

            -- Autocompletion
            { 'hrsh7th/nvim-cmp' },
            { 'hrsh7th/cmp-nvim-lsp' },
            { 'L3MON4D3/LuaSnip' },
        }
    },
    { 'nvim-treesitter/nvim-treesitter', build = ':TSUpdate' }
})

